Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(243)

Unified Diff: third_party/WebKit/Source/web/CompositorMutatorImpl.h

Issue 2515363002: Introduce AnimationWorkletProxyClient and necessary plumbing to get it in worklet messaging proxy. (Closed)
Patch Set: address feedback Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/CompositorMutatorImpl.h
diff --git a/third_party/WebKit/Source/web/CompositorMutatorImpl.h b/third_party/WebKit/Source/web/CompositorMutatorImpl.h
index 3cf1f18e71aed1961d1f2bc7a828f5f88d4ee20d..6fb44605c12162d5efabb2fd01d7ca8fd326ab44 100644
--- a/third_party/WebKit/Source/web/CompositorMutatorImpl.h
+++ b/third_party/WebKit/Source/web/CompositorMutatorImpl.h
@@ -15,13 +15,14 @@
namespace blink {
class CompositorProxy;
-class CompositorProxyClientImpl;
+class CompositorAnimator;
class CompositorMutatorClient;
// Fans out requests from the compositor to all of the registered ProxyClients
// which can then mutate layers through their CompositorProxy interfaces.
// Requests for animation frames are received from ProxyClients and sent to the
// compositor to generate a new compositor frame.
//
// Should be accessed only on the compositor thread.
class CompositorMutatorImpl final : public CompositorMutator {
@@ -35,8 +36,8 @@ class CompositorMutatorImpl final : public CompositorMutator {
bool mutate(double monotonicTimeNow,
CompositorMutableStateProvider*) override;
- void registerProxyClient(CompositorProxyClientImpl*);
- void unregisterProxyClient(CompositorProxyClientImpl*);
+ void registerCompositorAnimator(CompositorAnimator*);
+ void unregisterCompositorAnimator(CompositorAnimator*);
void setNeedsMutate();
@@ -48,9 +49,9 @@ class CompositorMutatorImpl final : public CompositorMutator {
private:
CompositorMutatorImpl();
- using ProxyClients =
- HashSet<CrossThreadPersistent<CompositorProxyClientImpl>>;
- ProxyClients m_proxyClients;
+ using CompositorAnimators =
+ HashSet<CrossThreadPersistent<CompositorAnimator>>;
+ CompositorAnimators m_animators;
std::unique_ptr<CustomCompositorAnimationManager> m_animationManager;
CompositorMutatorClient* m_client;
@@ -15,13 +15,14 @@
class CompositorMutatorClient;
-// Fans out requests from the compositor to all of the registered ProxyClients
-// which can then mutate layers through their CompositorProxy interfaces.
-// Requests for animation frames are received from ProxyClients and sent to the
-// compositor to generate a new compositor frame.
+// Fans out requests from the compositor to all of the registered
+// CompositorAnimators which can then mutate layers through their respective
+// mutate interface. Requests for animation frames are received from
+// CompositorAnimators and sent to the compositor to generate a new compositor
+// frame.
//
// Should be accessed only on the compositor thread.

Powered by Google App Engine
This is Rietveld 408576698